@@ -126,10 +126,7 @@ def subquery(query, relationship):
             else:
                 return_query['includes'] = {}
         elif key == 'filters':
-            if value and relationship in value.relationships:
-                return_query['filters'] = value.relationships[relationship]
-            else:
-                return_query['filters'] = {}
+            return_query['filters'] = {}
         elif key in ('sort', 'page'):
             return_query[key] = value
     return return_query
