@@ -24,6 +24,7 @@ from abc import abstractmethod
 from asyncio import Event, Lock, create_task, gather
 from itertools import chain
 from re import compile as re_compile
+from urllib.parse import unquote as urldecode
 
 from asyncpg.exceptions import (
     CheckViolationError,
@@ -44,6 +45,7 @@ from ajsonapi.environments import GetCollectionIncludedEnvironment
 from ajsonapi.errors import (
     FilterInvalidPathError,
     IncludeInvalidPathError,
+    QueryParameterDuplicateError,
     QueryParameterUnsupportedError,
     ResourceNotFoundError,
     SortInvalidFieldError,
@@ -180,13 +182,15 @@ class Collection(Resource):
         """Parses the request's include query parameter."""
 
         if query_has_parameter(request_query, 'include'):
-            if allow:
-                query['includes'] = {}
-                self.includes_dict(query['includes'],
-                                   request_query['include'].split(','), errors,
-                                   [])
-            else:
+            if not allow:
                 errors.append(QueryParameterUnsupportedError('include'))
+                return
+            if len(request_query.getall('include')) > 1:
+                errors.append(QueryParameterDuplicateError('include'))
+                return
+            query['includes'] = {}
+            self.includes_dict(query['includes'],
+                               request_query['include'].split(','), errors, [])
         else:
             query['includes'] = None
 
@@ -201,7 +205,7 @@ class Collection(Resource):
                     errors.append(QueryParameterUnsupportedError('filter'))
                     return
                 path = match.group(1)
-                filter_values = set(value.split(','))
+                filter_values = set(urldecode(v) for v in value.split(','))
                 filter_path_values.append((path, filter_values))
         if filter_path_values != []:
             query['filters'] = self.filters_tree(FilterNode(),
@@ -213,10 +217,13 @@ class Collection(Resource):
         """Parses the request's sort query parameter."""
 
         if query_has_parameter(request_query, 'sort'):
-            if allow:
-                query['sort'] = self.sort_list(request_query, errors)
-            else:
+            if not allow:
                 errors.append(QueryParameterUnsupportedError('sort'))
+                return
+            if len(request_query.getall('sort')) > 1:
+                errors.append(QueryParameterDuplicateError('sort'))
+                return
+            query['sort'] = self.sort_list(request_query, errors)
         else:
             query['sort'] = None
 
