@@ -325,8 +325,9 @@ class OneToManyRelatedResource(ToManyRelatedResource):
 
         filters = env.query['filters']
         if filters:
-            where_clause = (f' WHERE {self.relationship.rfkey} = $1 AND '
-                            f'{" AND ".join(filters)}')
+            where_clause = (
+                f' WHERE {self.relationship.rfkey} = $1 AND '
+                f'{" AND ".join(filters.conditions(rtable.collection))}')
         else:
             where_clause = f' WHERE {self.relationship.rfkey} = $1'
 
@@ -368,11 +369,12 @@ class ManyToManyRelatedResource(ToManyRelatedResource):
 
         filters = env.query['filters']
         if filters:
-            where_clause = (f' WHERE id IN ('
-                            f' SELECT {self.relationship.rafkey}'
-                            f' FROM data.{self.relationship.atable.name}'
-                            f' WHERE {self.relationship.lafkey} = $1) AND'
-                            f' {" AND ".join(filters)}')
+            where_clause = (
+                f' WHERE id IN ('
+                f' SELECT {self.relationship.rafkey}'
+                f' FROM data.{self.relationship.atable.name}'
+                f' WHERE {self.relationship.lafkey} = $1) AND'
+                f' {" AND ".join(filters.conditions(rtable.collection))}')
         else:
             where_clause = (f' WHERE id IN ('
                             f' SELECT {self.relationship.rafkey}'
